function check_ip(addr)
{
  var m = /^(\d+)\.(\d+)\.(\d+)\.(\d+)$/.exec(addr);

  // Is it a dotted quad?
  if ( !m )
    return 'Invalid address format';

  // Will the numbers fit in a byte?
  if (    m[1] < 0 || m[1] > 255
       || m[2] < 0 || m[2] > 255
       || m[3] < 0 || m[3] > 255
       || m[4] < 0 || m[4] > 255 )
    return 'Number out of range';

  // RFC 1918
  if ( m[1] == 10 )
    return 'Internal address (RFC 1918)';
  if ( m[1] == 192 && m[2] == 168 )
    return 'Internal address (RFC 1918)';
  if ( m[1] == 172 && m[2] >= 16 && m[2] <= 31 )
    return 'Internal address (RFC 1918)';

  // Other random RFCs
  if ( m[1] == 0 && m[2] == 0 && m[3] == 0 )
    return 'This network (RFC 1700)';
  if ( m[1] == 14 )
    return 'Public data network (RFC 1700)';
  if ( m[1] == 24 )
    return 'Cable TV network (RFC 1700)';
  if ( m[1] == 39 )
    return 'Reserved but subject to allocation (RFC 1700)';
  if ( m[1] == 127 )
    return 'Loopback (RFC 1700)';

  if ( m[1] == 128 && m[2] == 0 )
    return 'Reserved but subject to allocation';
  if ( m[1] == 169 && m[2] == 254 )
    return 'Link local';
  if ( m[1] == 191 && m[2] == 255 )
    return 'Reserved but subject to allocation';
  if ( m[1] == 192 && m[2] == 0 && m[3] == 0 )
    return 'Reserved but subject to allocation';
  if ( m[1] == 192 && m[2] == 0 && m[3] == 2 )
    return 'Test-Net';
  if ( m[1] == 192 && m[2] == 88 && m[3] == 99 )
    return '6 to 4 Relay Anycast';
  if ( m[1] == 198 && m[2] >= 18 && m[2] <= 19 )
    return 'Network Interconnect Device Benchmark Testing';
  if ( m[1] == 223 && m[2] == 255 && m[3] == 255 )
    return 'Reserved but subject to allocation';
  if ( m[1] >= 224 && m[1] <= 239 )
    return 'Multicast';
  if ( m[1] >= 240 && m[1] <= 255 )
    return 'Reserved';

  return 'Valid external address';
}
